#Lasrs
lasrs is a crate used to parse geophysical well log files .las.
Provides utilities for extracting strongly typed information from the files.
Supports Las Version 2.0 by Canadian Well Logging Society -
Specification
Structs
- Represents a parsed well log file
- Wellprop represents an entry in every sections excluding ~O, ~A and ~V (other, data and version sections respectively)